﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;
using HeuristicLab.Data.Views;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Histogram View")]
  [Content(typeof(HistogramContent), false)]
  public partial class HistogramView : ItemView {
    public HistogramView() {
      InitializeComponent();
    }

    public new HistogramContent Content {
      get { return (HistogramContent)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content != null) {
        InitDataTable();
        InitVariablesListBox();
      }
    }

    private void InitVariablesListBox() {
      IHistogramLogic logic = Content.HistogramLogic;

      foreach (var variableName in logic.GetVariableNames()) {
        variablesListBox.Items.Add(variableName, true);
      }
    }

    private void InitDataTable() {
      IHistogramLogic logic = Content.HistogramLogic;
      viewHost.Content = logic.GetDataTable();
    }

    private void variablesListBox_ItemCheck(object sender, ItemCheckEventArgs e) {
      string item = variablesListBox.Items[e.Index] as string;

      if (e.NewValue == CheckState.Checked && !Content.HistogramLogic.VariableIsDisplayed(item))
        Content.HistogramLogic.AddVariable(item);
      else if (e.NewValue == CheckState.Unchecked && Content.HistogramLogic.VariableIsDisplayed(item))
        Content.HistogramLogic.RemoveVariable(item);
    }
  }
}





