﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Windows.Forms;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using HeuristicLab.MainForm.WindowsForms;

namespace HeuristicLab.DataPreprocessing.Views {

  [View("Line Chart View")]
  [Content(typeof(LineChartContent), false)]
  public partial class LineChartView : ItemView {

    public LineChartView() {
      InitializeComponent();
    }

    private void InitDataTable() { 
      ILineChartLogic logic = Content.LineChartLogic;
      viewHost.Content = logic.GetDataTable();
    }

    public new LineChartContent Content {
      get { return (LineChartContent)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content != null) {
        InitDataTable();
        InitVariablesListBox();
      }
    }

    private void InitVariablesListBox() {
      ILineChartLogic logic = Content.LineChartLogic;

      foreach (var variableName in logic.GetVariableNames()) {
        variablesListBox.Items.Add(variableName, true);
      }
    }

    private void variablesListBox_ItemCheck(object sender, ItemCheckEventArgs e) {
      string item = variablesListBox.Items[e.Index] as string;


      if (e.NewValue == CheckState.Checked && !Content.LineChartLogic.VariableIsDisplayed(item))
        Content.LineChartLogic.AddVariable(item);
      else if (e.NewValue == CheckState.Unchecked && Content.LineChartLogic.VariableIsDisplayed(item))
        Content.LineChartLogic.RemoveVariable(item);
    }
  }
}


